import { initIssues, initCounters } from './issues/initializers.js';
import { relative } from './util/path.js';
export class IssueCollector {
    cwd;
    issues = initIssues();
    counters = initCounters();
    referencedFiles = new Set();
    constructor({ cwd }) {
        this.cwd = cwd;
    }
    addTotalFileCount(count) {
        this.counters.total += count;
    }
    addFilesIssues(filePaths) {
        filePaths.forEach(filePath => {
            if (!this.referencedFiles.has(filePath)) {
                this.issues.files.add(filePath);
                this.counters.files++;
                this.counters.processed++;
            }
        });
    }
    addIssue(issue) {
        const key = relative(this.cwd, issue.filePath);
        this.issues[issue.type][key] = this.issues[issue.type][key] ?? {};
        if (!this.issues[issue.type][key][issue.symbol]) {
            this.issues[issue.type][key][issue.symbol] = issue;
            this.counters[issue.type]++;
        }
    }
    getIssues() {
        return {
            issues: this.issues,
            counters: this.counters,
        };
    }
}
